# libPythonPro
Módulo para exemplificar ferramentas no PyTools

Neste curso foi ensinado como contribuir para projetos de código aberto.

Link para o curso [Python Pro](https://www.python.pro.br/)

[![Updates](https://pyup.io/repos/github/Rafael-Fonseca/libPythonPro/shield.svg)](https://pyup.io/repos/github/Rafael-Fonseca/libPythonPro/)
[![Python 3](https://pyup.io/repos/github/Rafael-Fonseca/libPythonPro/python-3-shield.svg)](https://pyup.io/repos/github/Rafael-Fonseca/libPythonPro/)
[![codecov](https://codecov.io/gh/Rafael-Fonseca/libPythonPro/branch/main/graph/badge.svg?token=14MCK5SAW3)](https://codecov.io/gh/Rafael-Fonseca/libPythonPro)

Para instalar, digite no console:

'''

python3 -m venv .venv

source .venv/bin/activave

pip install-r requirements-dev.txt

'''

Para conferir a qualidade de código:

"""

flake8

"""

Tópicos a serem abordados:

1. Git

2.VirtualEnv

3.Pip